from pathlib import Path

# Build paths inside the project like this: BASE_DIR / "subdir".
BASE_DIR = Path(__file__).resolve().parent.parent

USE_TZ = True

DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"

SECRET_KEY = "django-seriously-insecure"

DEBUG = True

INSTALLED_APPS = [
    "django_migrations_ci.tests.testapp",
    "django_migrations_ci",
]

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": BASE_DIR / "db.sqlite3",
        "TEST": {
            "NAME": "dbtest.sqlite3",
        },
    }
}

ROOT_URLCONF = "django_migrations_ci.tests.testapp.urls"



import os

from django.core.management import execute_from_command_line


def test_clone_database():
    # TODO: Cleanup files before the test.
    execute_from_command_line(["manage.py", "setup_test_db"])
    execute_from_command_line(["manage.py", "clone_test_db", "2", "--suffix", "foo"])
    assert os.path.exists("dbtest_foo1.sqlite3")
    assert os.path.exists("dbtest_foo2.sqlite3")
    assert not os.path.exists("dbtest_foo3.sqlite3")



from django.apps import apps
from django.core.management import execute_from_command_line


def test_setup_database():
    execute_from_command_line(["manage.py", "setup_test_db"])
    # Migrations create one bus.
    Bus = apps.get_model("testapp", "Bus")
    assert Bus.objects.count() == 1



from django.conf import settings
from django.core.management.base import BaseCommand
from django.db import connections
from django.test.runner import get_max_test_processes


class Command(BaseCommand):
    """
    Copy the test database to support parallel tests.
    """

    def add_arguments(self, parser):
        parser.add_argument("parallel")
        # pytest-django uses test_db_gwN, from 1 to N worker processes.
        parser.add_argument("-s", "--suffix", default="")

    def handle(self, parallel, *args, suffix, **options):
        if parallel == "auto":
            parallel = get_max_test_processes()
        else:
            parallel = int(parallel)

        connection = connections["default"]
        settings.DATABASES[connection.alias][
            "NAME"
        ] = connection.creation._get_test_db_name()

        # https://github.com/pytest-dev/pytest-django/blob/e0c77b391ea54c3b8d6ffbb593aa25188a0ce7e9/pytest_django/fixtures.py#L61
        for index in range(1, parallel + 1):
            connection.creation.clone_test_db(
                suffix=f"{suffix}{index}",
                verbosity=True,
                keepdb=False,
            )



from django.core.management.base import BaseCommand
from django.test.utils import setup_databases


class Command(BaseCommand):
    """
    Use Django to setup databases.
    """

    def handle(self, *args, **options):
        # Based on https://github.com/django/django/blob/d62563cbb194c420f242bfced52b37d6638e67c6/django/test/runner.py#L1051-L1054  # noqa: E501
        # TODO: Handle aliases better.
        setup_databases(verbosity=True, interactive=False, aliases=["default"])
